==> deep_pipe-0.4.1.tar.gz: deep_pipe-0.4.1/setup.py <==
from pathlib import Path

from setuptools import setup, find_packages

classifiers = '''Development Status :: 4 - Beta
Programming Language :: Python :: 3.6
Programming Language :: Python :: 3.7
Programming Language :: Python :: 3.8
Programming Language :: Python :: 3.9
Programming Language :: Python :: 3.10
Programming Language :: Python :: 3.11
Programming Language :: Python :: 3.12'''

with open('README.md', encoding='utf-8') as file:
    long_description = file.read()

with open('requirements.txt', encoding='utf-8') as file:
    requirements = file.read().splitlines()

with open(Path(__file__).resolve().parent / 'dpipe/__version__.py', encoding='utf-8') as file:
    scope = {}
    exec(file.read(), scope)
    __version__ = scope['__version__']

setup(
    name='deep_pipe',
    packages=find_packages(include=('dpipe',)),
    include_package_data=True,
    version=__version__,
    description='A collection of tools for deep learning experiments',
    long_description=long_description,
    author='NeuroML Group',
    long_description_content_type='text/markdown',
    license='MIT',
    url='https://github.com/neuro-ml/deep_pipe',
    download_url='https://github.com/neuro-ml/deep_pipe/v%s.tar.gz' % __version__,
    keywords=[],
    classifiers=classifiers.splitlines(),
    install_requires=requirements,
    python_requires='>=3.6',
    entry_points={
        'console_scripts': [
            'dpipe-run = dpipe.layout.scripts:run',
            'dpipe-build = dpipe.layout.scripts:build',
        ],
    },
)

==> deep_pipe-0.4.2.tar.gz: deep_pipe-0.4.2/setup.py <==
from pathlib import Path

from setuptools import setup, find_packages


classifiers = [
    'Development Status :: 4 - Beta',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
    'Programming Language :: Python :: 3.10',
    'Programming Language :: Python :: 3.11',
    'Programming Language :: Python :: 3.12',
    'Programming Language :: Python :: 3.13',
    'Programming Language :: Python :: 3 :: Only',
]

with open('README.md', encoding='utf-8') as file:
    long_description = file.read()

with open('requirements.txt', encoding='utf-8') as file:
    requirements = file.read().splitlines()

with open(Path(__file__).resolve().parent / 'dpipe/__version__.py', encoding='utf-8') as file:
    scope = {}
    exec(file.read(), scope)
    __version__ = scope['__version__']

setup(
    name='deep_pipe',
    packages=find_packages(include=('dpipe',)),
    include_package_data=True,
    version=__version__,
    description='A collection of tools for deep learning experiments',
    long_description=long_description,
    author='NeuroML Group',
    long_description_content_type='text/markdown',
    license='MIT',
    url='https://github.com/neuro-ml/deep_pipe',
    download_url='https://github.com/neuro-ml/deep_pipe/v%s.tar.gz' % __version__,
    keywords=[],
    classifiers=classifiers,
    install_requires=requirements,
    python_requires='>=3.7',
    entry_points={
        'console_scripts': [
            'dpipe-run = dpipe.layout.scripts:run',
            'dpipe-build = dpipe.layout.scripts:build',
        ],
    },
)
